
# Python-ms Changelog

All notable changes to this project will be documented in this file.

The format is based on [CHANGELOG.md](http://changelog.md/)
and this project adheres to [Semantic Versioning](http://semver.org/).

<!-- 
TEMPLATE

## [major.minor.patch] - yyyy-mm-dd

A message that notes the main changes in the update.

### Added

### Changed

### Deprecated

### Fixed

### Removed

### Security

_______________________________________________________________________________
 
 -->

<!--
EXAMPLE

## [0.2.0] - 2021-06-02

Lorem Ipsum dolor sit amet.

### Added

- Cat pictures hidden in the library
- Added beeswax to the gears

### Changed

- Updated localisation files

-->

<!--
_______________________________________________________________________________

## [1.0.0] - 2022-12-20

This update fixes a handful of things, readying the package for official
release.

### Added

- Badges to `README.md`

### Changed

- Updated GitHub Actions workflows to use newer versions

### Fixed

- Swapped `Ellipsis` for `pass` in the hopes of getting coverage reports ignore
  them

-->

_______________________________________________________________________________

## [1.0.0] - 2022-12-20

This update fixes a handful of things, readying the package for official
release.

### Added

- Badges to `README.md`

### Changed

- Updated GitHub Actions workflows to use newer versions

### Fixed

- Swapped `Ellipsis` for `pass` in the hopes of getting coverage reports ignore
  them

_______________________________________________________________________________

## [0.9.0] - 2022-12-20

This update adds all planned fuctionality for the project.
Strings are parsed into integers, and vice versa.

### Added

- String to int conversion for microseconds
- Int to string conversion for microseconds
- Added more GitHub Actions workflows for PyPI uploads
- Full unit test coverage

### Changed

- Moved constants to their own file
- Updated linters and cleaned up the codebase
- Updated localisation files

### Fixed

- Fixed a bug with the regex query

_______________________________________________________________________________

## [0.1.0] - 2022-12-17

This is the initial version of the project.

### Added

- The base project

<!-- markdownlint-configure-file {
    "MD022": false,
    "MD024": false,
    "MD030": false,
    "MD032": false
} -->
<!--
    MD022: Blanks around headings
    MD024: No duplicate headings
    MD030: Spaces after list markers
    MD032: Blanks around lists
-->
